Name:		openvas-libraries
Summary:	Support libraries for Open Vulnerability Assessment (OpenVAS) Scanner
URL:		http://www.openvas.org
License:	LGPLv2
Group:		System Environment/Libraries
Version:	4.0.7
Release:	3%{?dist}
Source0:	http://wald.intevation.org/frs/download.php/1053/%{name}-%{version}.tar.gz
Source1:	https://svn.wald.intevation.org/svn/openvas/trunk/tools/openvas-check-setup

#Reported as bug 1942	Fix compile time errors - variable 'xxx' set but not used
#http://wald.intevation.org/tracker/index.php?func=detail&aid=1942&group_id=29&atid=220
Patch0:		openvas-libraries-notused.patch

#Reported as bug 2526	Fix compile time errors - gnutsl deprecated functions
#http://wald.intevation.org/tracker/index.php?func=detail&aid=2526&group_id=29&atid=220
Patch1:		openvas-libraries-gnutls.patch
Patch2:		openvas-libraries-lowat.patch

#Disable compile Werror flag to avoid stopping the compilation on warning about deprecated
#gnutls functions for setting priorities - I use this mainly because of the current issues 
#with SIGSEG in gnutls. Once resolved the gnutls and lowat patch should be used instead.
Patch3:		openvas-libraries-nowerror.patch

#https://bugzilla.redhat.com/show_bug.cgi?id=747167
#http://wald.intevation.org/tracker/index.php?func=detail&aid=6277&group_id=29&atid=220
#Premature releasing of the memory used by the private key results on Fedora 16 on
#SIGSEGV situation when the key material is used later on in _gnutls_pkcs1_rsa_decrypt.
#Due to reuse of released memory and wrong boundary checking in the _gnutls_pkcs1_rsa_decrypt
#overwrites whole stack and causes crash.
#Relevant only to gnutls-2.12.0 - 2.12.10
#Not needed anymore as gnutls in Fedora 16 is being pushed to version 2.12.14
#Patch4:		openvas-libraries-key.patch

Patch5: 	openvas-lsc-rpm-creator.sh.patch

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
Obsoletes:	openvas-libnasl
BuildRequires:	glib2-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	gnutls-devel >= 2.12.10
BuildRequires:	libpcap-devel
BuildRequires:	libuuid-devel
BuildRequires:	gpgme-devel
BuildRequires:	cmake >= 2.6.0
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	pkgconfig
BuildRequires:	doxygen
BuildRequires:	openldap-devel


%description
openvas-libraries is the base library for the OpenVAS network
security scanner.


%package devel
Summary:	Development files for openvas-libraries
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Development libraries and headers for use with %{name}.


%package doc
Summary:	Documentation for %{name}
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
This package contains documentation for %{name}.


%prep
%setup -q
#%patch0 -p 1 -b .notused.patch
#Patch for gnutls > 2.12.0
#%patch1 -p 1 -b .gnutls.patch
#%patch2 -p 1 -b .lowat.patch

#Used mainly to troubleshoot SIGSEG in gnutls. Once solved patch1/2 shuold be used instead
%patch3 -p 1 -b .nowerror.patch

#Avoid SIGSEG in gnutls.
#patch4 -p 1 -b .key.patch

%patch5 -p1 -b .rpm

#Fix FSF address in source files - FIXED in 4.0.7
#OLDADDR="675 Mass Ave, Cambridge, MA 02139, USA"
#NEWADDR="51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA"
#LIST=`grep -lre "$OLDADDR" *| grep -E '.c$|.h$|.y$|COPYING'`
#echo "$LIST" | xargs sed -i -e "s/$OLDADDR/$NEWADDR/" 

#OLDADDR="59 Temple Place - Suite 330, Boston, MA 02111-1307, USA"
#sed -i -e "s/$OLDADDR/$NEWADDR/" nasl/smb_crypt.c nasl/smb_crypt.h

#Fix codepage of the Changelog
iconv -f LATIN1 -t UTF8 < ChangeLog > ChangeLog1
mv ChangeLog1 ChangeLog


%build
#export CFLAGS=-Werror=unused-but-set-variable
%cmake -DLOCALSTATEDIR:PATH=%{_var} -DBUILD_WITH_LDAP=ON
# No parallel build because it causes compilation problems
make
make doc

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL="install -p"
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Remove static libraries
find %{buildroot} -name '*.a' -exec rm -f {} ';'

## Currently I don't know for what is this used so I removing it
#rm -f %{buildroot}/%{_datadir}/openvas/openvas-lsc-rpm-creator.sh

#Install openvas-check-setup
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README COPYING* ChangeLog CHANGES
%dir %{_datadir}/openvas
%dir %{_sysconfdir}/openvas
%{_bindir}/openvas-nasl
%{_bindir}/openvas-check-setup
%{_mandir}/man1/openvas-nasl.1.*
%{_libdir}/libopenvas_base.so.*
%{_libdir}/libopenvas_hg.so.*
%{_libdir}/libopenvas_misc.so.*
%{_libdir}/libopenvas_nasl.so.*
%{_libdir}/libopenvas_omp.so.*
%{_datadir}/openvas/openvas-services
%{_datadir}/openvas/openvas-lsc-rpm-creator.sh

%files devel
%defattr(-,root,root,-)
%{_includedir}/openvas/
%{_libdir}/libopenvas_base.so
%{_libdir}/libopenvas_hg.so
%{_libdir}/libopenvas_misc.so
%{_libdir}/libopenvas_nasl.so
%{_libdir}/libopenvas_omp.so
%{_libdir}/pkgconfig/libopenvas.pc

%files doc
%defattr(-,root,root,-)
%doc doc/generated/html
%doc doc/example.auth.conf
%doc doc/example.target.locators
%doc doc/signatures-howto.txt
%doc doc/test_ipv6_packet_forgery.nasl
%doc doc/wmi-howto.txt


%changelog
* Wed Aug 15 2012 josef radinger <cheese@nosuchhost.net> - 4.0.7-3
- fix openvas-lsc-rpm-creator.sh

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Mar 26 2012 Michal Ambroz <rebus at, seznam.cz> - 4.0.7-1
- adding openvas-check-setup based on suggestion of Reindl Harald
- bump to version 4.0.7

* Tue Jan 24 2012 Michal Ambroz <rebus at, seznam.cz> - 4.0.6-4
- separate documentation package, build with ldap support

* Sun Jan 15 2012 Michal Ambroz <rebus at, seznam.cz> - 4.0.6-3
- removed pach openvas-libraries-4.0.6-key.patch again as gnutls will be
  upgraded to 2.2.14 in Fedora 16 soon

* Mon Jan 09 2012 Michal Ambroz <rebus at, seznam.cz> - 4.0.6-2
- added openvas-libraries-4.0.6-key.patch to fix use-after-free issue causing
  SIGSEGV fault in gnutls code

* Fri Nov 04 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.6-1
- bump to version 4.0.6

* Thu Oct 18 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.5-5
- revert back to code withou gnutls modifications to confirm gnutls
issues are not caused by it
- disabling the -Werror to avoid compilation issues with the deprecated gnutls code

* Thu Oct 06 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.5-4
- fix the priorities string

* Sat Jul 30 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.5-3
- gnutls > 2.12.0 has deprecated gnutls_transport_set_lowat

* Sun Jul 3 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.5-2
- change from deprecated gnutls_*_set_priority to gnutls_priority_set_direct

* Fri Jun 10 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.5-1
- bump to 4.0.5

* Fri May 06 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.4-1
- bump to 4.0.4

* Tue Mar 22 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.3-2
- patch not used

* Fri Mar 18 2011 Michal Ambroz <rebus at, seznam.cz> - 4.0.3-1
- Bump to latest stable release 4

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Nov 20 2010 Stjepan Gros <stjepan.gros@gmail.com> - 3.1.4-1
- Bump to latest stable release
- Added libuuid-devel build time dependency

* Mon Apr 5 2010 Huzaifa Sidhpurwala <huzaifas@redhat.com> - 3.0.3-3
- Obsolete openvas-libnasl

* Wed Mar 3 2010 Huzaifa Sidhpurwala <huzaifas@redhat.com> - 3.0.3-2
- Correct license to LGPLv2

* Mon Mar 1 2010 Huzaifa Sidhpurwala <huzaifas@redhat.com> - 3.0.3-1
- Upgraded to a new upstream version
- Spec from Stjepan Gros

* Wed Nov 26 2009 Huzaifa Sidhpurwala <huzaifas@redhat.com> 2.0.4-3
- Update to 2.0.4.
- Fix %%setup invocation.
- Add BR: glib2-devel.
- Version bump so that it builds

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Oct 13 2008 Huzaifa Sidhpurwala <huzaifas@redhat.com> 1.0-2-2
- More changes to the spec

* Wed Sep 9 2008 Huzaifa Sidhpurwala <huzaifas@redhat.com> 1.0.2-1
- Built on newer upstream version
- Minor spec changes

* Wed Sep 9 2008 Huzaifa Sidhpurwala <huzaifas@redhat.com> 1.0.1-1
- Inital Fedora version

* Tue Apr 15 2008 Jan-Oliver Wagner <jan-oliver.wagner@intevation.de>
  Initial SUSE 10.2 spec file, tested for i586
